# Config File 

> Manage your configuration files

[![Python 3.8.0|](https://img.shields.io/badge/python-3.8.0-blue.svg)](https://www.python.org/downloads/release/python-380/) 
[![Version](https://img.shields.io/pypi/v/config-file)](https://pypi.org/project/config-file/)
[![Style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://pypi.org/project/black/)

This python package is currently a work in progress and should not be used in a 
production environment. The API is liable to break at anytime until 1.0.0.

Config File allows you to use the same API and package for manipulating INI, JSON, 
YAML, and TOML configuration files. For the time being, it only supports INI.